package com.ynet.life.util;

import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.Writer;

/* loaded from: com_ynet_life_util.jar:com/ynet/life/util/CSVWriter.class */
public class CSVWriter {
    PrintWriter pw;
    boolean forceQuotes;
    char separator;
    boolean wasPreviousField;
    String comment;
    String lineSeparator;

    public CSVWriter(PrintWriter pw, boolean forceQuotes, char separator, String lineSeparator) {
        this.wasPreviousField = false;
        this.pw = pw;
        this.forceQuotes = forceQuotes;
        this.separator = separator;
        this.comment = "# ";
        this.lineSeparator = lineSeparator;
    }

    public CSVWriter(Writer w, boolean forceQuotes, char separator, String lineSeparator) {
        this(new PrintWriter(w), forceQuotes, separator, lineSeparator);
    }

    public CSVWriter(PrintWriter pw) {
        this.wasPreviousField = false;
        this.pw = pw;
        this.forceQuotes = false;
        this.separator = ',';
        this.comment = "# ";
        this.lineSeparator = System.getProperty("line.separator");
    }

    public CSVWriter(Writer w) {
        this(new PrintWriter(w));
    }

    public CSVWriter(PrintWriter pw, char comment) {
        this.wasPreviousField = false;
        this.pw = pw;
        this.forceQuotes = false;
        this.separator = ',';
        this.comment = String.valueOf(String.valueOf(comment)) + " ";
        this.lineSeparator = System.getProperty("line.separator");
    }

    public CSVWriter(Writer w, char comment) {
        this(new PrintWriter(w), comment);
    }

    public void writeCommentln(String text) {
        if (this.wasPreviousField) {
            writeln();
        }
        this.pw.print(this.comment);
        write(text);
        writeln();
    }

    public void writeln(String token) {
        write(token);
        writeln();
    }

    public void writeln() {
        this.wasPreviousField = false;
        this.pw.print(this.lineSeparator);
    }

    public void writeln(String[] line) {
        for (String str : line) {
            write(str);
        }
        writeln();
    }

    public void write(String s) {
        if (this.wasPreviousField) {
            this.pw.print(this.separator);
        }
        if (s == null) {
            this.pw.print("");
            return;
        }
        if (s.indexOf(34) >= 0) {
            this.pw.print('\"');
            for (int i = 0; i < s.length(); i++) {
                char c = s.charAt(i);
                if (c != '\"') {
                    this.pw.print(c);
                } else {
                    this.pw.print("\"\"");
                }
            }
            this.pw.print('\"');
        } else if (s.indexOf(10) >= 0) {
            this.pw.print('\"');
            for (int i2 = 0; i2 < s.length(); i2++) {
                char c2 = s.charAt(i2);
                if (c2 != '\n') {
                    this.pw.print(c2);
                } else {
                    this.pw.print("\\n");
                }
            }
            this.pw.print('\"');
        } else if (this.forceQuotes || s.indexOf(this.separator) >= 0) {
            this.pw.print('\"');
            this.pw.print(s);
            this.pw.print('\"');
        } else {
            this.pw.print(s);
        }
        this.wasPreviousField = true;
    }

    public void close() {
        if (this.pw != null) {
            this.pw.close();
            this.pw = null;
        }
    }

    /* JADX WARN: Type inference failed for: r0v3, types: [com.ynet.life.util.CSVWriter, java.io.IOException] */
    public static void main(String[] args) {
        ?? cSVWriter;
        try {
            PrintWriter lPw = new PrintWriter(new FileWriter(args[0]));
            cSVWriter = new CSVWriter(lPw, false, ',', System.getProperty("line.separator"));
            cSVWriter.writeCommentln("This is a test csv-file: '" + args[0] + "'");
            cSVWriter.write("abc");
            cSVWriter.write("def");
            cSVWriter.write("g h i");
            cSVWriter.write("jk,l");
            cSVWriter.write("m\"n'o ");
            cSVWriter.writeln();
            cSVWriter.write("m\"n'o ");
            cSVWriter.write("    ");
            cSVWriter.write("a");
            cSVWriter.write("x,y,z");
            cSVWriter.write("x;y;z");
            cSVWriter.writeln();
            cSVWriter.writeln(new String[]{"This", "is", "an", "array."});
            cSVWriter.close();
        } catch (IOException e) {
            cSVWriter.printStackTrace();
            System.out.println(e.getMessage());
        }
    }
}
